<?php
class calendarProject extends projectModel
{
    public function getTasks4Calendar($projectID, $status = 'all', $orderBy = 'status_asc, id_desc', $pager = null)
    {
        $tasks   = $this->loadmodel('task')->getProjectTasks($projectID, $productID = 0, $status, $modules = 0, $orderBy, $pager); 
        $actions = $this->dao->select('*')->from(TABLE_ACTION)->where('objectType')->eq('task')->andWhere('project')->eq($projectID)->andWhere('action')->in('started,finished')->fetchGroup('objectID');
        $project = $this->getById($projectID);

        foreach($tasks as $taskID => $task)
        {
            if(!empty($task->children))
            {
                foreach($task->children as $task) $tasks[$task->id] = $task;
                unset($tasks[$taskID]);
            }
        }
        
        $events = array();
        foreach($tasks as $task)
        {
            $event['id']       = $task->id;
            $event['title']    = $task->name;
            $event['status']   = $task->status;
            $event['start']    = '';
            $event['end']      = '';
            if($task->estStarted  != '0000-00-00') $event['start'] = $task->estStarted;
            if($task->realStarted != '0000-00-00') $event['start'] = $task->realStarted;
            if($task->deadline != '0000-00-00')    $event['end']   = $task->deadline;
            if(empty($event['start'])) $event['start'] = $project->begin;
            if(empty($event['end']))   $event['end']   = $project->end;
            if($task->parent > 0) $event['title'] = '[' . $this->lang->task->childrenAB . ']' . $event['title'];

            if(isset($actions[$task->id]))
            {
                foreach($actions[$task->id] as $action)
                {
                    $event['actor']  = $action->actor;
                    $event['action'] = $action->action;
                    if($action->action == 'started')
                    {
                        $event['start'] = $action->date;
                    }
                    elseif($action->action == 'finished')
                    {
                        $event['end'] = $action->date;
                    }
                }
            }

            /* Judge the date of task, make sure the date in one day. */
            if($event['start'] == $project->begin and $event['end'] == $project->end) $event['end'] = $project->begin;
            if(helper::diffDate($event['end'], $event['start']) > 1)
            {
                if($event['start'] != $project->begin) $event['end']   = $event['start'];
                if($event['start'] == $project->begin) $event['start'] = $event['end'];
            }

            $date = date('Y-m-d', strtotime($event['start']));
            $event['cacheId'] = substr($date, 0, 7);
            $event['url']     = helper::createLink("task", 'view', "id=$task->id", '', true);
            
            /* Fix bug for safari display */
            $event['start'] = date(DT_DATE1, strtotime($event['start']));
            $event['end']   = date(DT_DATE1, strtotime($event['end']));
            $events[$event['cacheId']][$date][] = $event;
        }
        ksort($events);
        return $events;
    }

    public function getEfforts4Calendar($projectID, $account = '', $year = '')
    {
        $efforts = $this->dao->select('t1.*,t2.dept')->from(TABLE_EFFORT)->alias('t1')
            ->leftJoin(TABLE_USER)->alias('t2')->on('t1.account=t2.account')
            ->where('t1.project')->eq($projectID)
            ->beginIF($account != '')->andWhere('t1.account')->eq($account)->fi()
            ->beginIF($year)->andWhere("(LEFT(t1.`date`, 4) = '$year')")->fi()
            ->fetchAll();

        /* Set session. */
        $this->session->set('effortReportCondition', '');
        $sql = explode('WHERE', $this->dao->get());
        if(isset($sql[1]))
        {
            $sql = explode('ORDER', $sql[1]);
            $this->session->set('effortReportCondition', $sql[0]);
        }

        $events = array();
        $users  = $this->loadModel('user')->getPairs('noletter');
        $space  = common::checkNotCN() ? ' ' : '';
        foreach($efforts as $id => $effort)
        {
            $event['id']       = $effort->id;
            $event['start']    = $effort->date;
            $event['end']      = $effort->date;
            $event['url']      = helper::createLink("$effort->objectType", 'view', "id=$effort->objectID", '', true);
            $event['consumed'] = $effort->consumed;
            $event['title']    = $effort->work;
            $event['divTitle'] = zget($users, $effort->account) . $space . $effort->work;
            if(strpos($effort->work, $this->lang->project->finished) !== false) $event['title'] = str_replace($this->lang->project->finished, zget($users, $effort->account) . "<i class='icon-task-finish icon-checked'></i>",  $effort->work);
            if(strpos($effort->work, $this->lang->project->started) !== false) $event['title'] = str_replace($this->lang->project->started, zget($users, $effort->account) . "<i class='icon-task-start icon-play'></i>",  $effort->work);
            $event['account']  = $effort->account;
            if($effort->objectType == 'case')   $event['url']   = helper::createLink('testcase', 'view', "id=$id", '', true);
            if($effort->objectType == 'custom') $event['url']   = '';
            if($effort->objectType != 'custom') $event['title'] = '[' . strtoupper($effort->objectType{0}) . ']' . $event['title'];

            $events[] = $event;
        }
        return json_encode($events);
    }
}
